==> syncope-2.1.0-source-release.zip: syncope-2.1.0/README.md <==
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->
**Apache Syncope** is an Open Source system for managing digital identities in enterprise environments, 
implemented in Java EE technology and released under Apache 2.0 license.

More information at http://syncope.apache.org

<a href="https://bestpractices.coreinfrastructure.org/projects/154">
  <img src="https://bestpractices.coreinfrastructure.org/projects/154/badge"/>
</a>
<a href="#">
  <img src="https://img.shields.io/maven-central/v/org.apache.syncope/syncope.svg"/>
</a>
<a href="https://travis-ci.org/apache/syncope"><img src="https://api.travis-ci.org/apache/syncope.png"/></a>
<a href="https://ci.appveyor.com/project/ApacheSoftwareFoundation/syncope">
  <img src="https://ci.appveyor.com/api/projects/status/k3moao48iilrq2pw?svg=true"/>
</a>

==> syncope-4.0.3-source-release.zip: syncope-4.0.3/README.md <==
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->
**Apache Syncope** is an Open Source system for managing digital identities in enterprise environments, 
implemented in Java EE technology and released under Apache 2.0 license.

More information at https://syncope.apache.org

<a href="https://bestpractices.coreinfrastructure.org/projects/154">
  <img src="https://bestpractices.coreinfrastructure.org/projects/154/badge"/>
</a>
<a href="#">
  <img src="https://img.shields.io/maven-central/v/org.apache.syncope/syncope.svg"/>
</a>
<a href="https://github.com/apache/syncope/actions/workflows/crosschecks.yml">
  <img src="https://github.com/apache/syncope/actions/workflows/crosschecks.yml/badge.svg"/>
</a>
<a href="https://github.com/apache/syncope/actions/workflows/codeql-analysis.yml">
  <img src="https://github.com/apache/syncope/actions/workflows/codeql-analysis.yml/badge.svg"/>
</a>
